package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````_"(```````!``````````#@!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0````````````````````````````````````"@`````````*``````````
M``$```````$````&````*/L````````H^P$``````"C[`0``````4`4`````
M``"X%0```````````0```````@````8```!(^P```````$C[`0``````2/L!
M``````#``0```````,`!````````"`````````!0Y71D!````.2:````````
MY)H```````#DF@```````,P`````````S``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````H^P```````"C[`0``````*/L!``````#8!```````
M`-@$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!-`````@````<```":A0`("4`$24B.%$&*A`#H`````$T```!1
M````50```%8```!;````7````%T`````````7P``````````````8````&$`
M``!B``````````````!J?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-\0[49-1\(?_D
M#MEQ6!SZH6Q@PN4_++(!BV_B1\8!N^.2?%7#/-)GK\QFB`=PTT-%U>PS8MOM
M?ZF<F^&G`@JCX/M)```````````````````````````````````````````#
M``<`>!@````````````````````````#``T`*/L!``````````````````P`
M```28````````````````````````+\!```28```````````````````````
M`!0````1`````````````````````````.4!```1````````````````````
M`````&$!```28````````````````````````!L````28```````````````
M`````````)X!```28````````````````````````",````28```````````
M`````````````/(!```28````````````````````````*H!```28```````
M`````````````````"H````@`````````````````````````#4#```A````
M`````````````````````$(````28````````````````````````$@````2
M`````````````````````````$\````2``````````````````````````(#
M```28````````````````````````/,"```28```````````````````````
M`'<"```28````````````````````````%8````2````````````````````
M`````!@"```28````````````````````````%T````28```````````````
M`````````*P"```28````````````````````````&0````28```````````
M`````````````&P````2`````````````````````````)4"```28```````
M`````````````````'0````28````````````````````````'H````28```
M`````````````````````(,````@`````````````````````````.P"```2
M8````````````````````````)\````28````````````````````````*0`
M```28`````````````````````````,"```1````````````````````````
M`+,"```28````````````````````````$4"```28```````````````````
M`````*L````28````````````````````````#<"```28```````````````
M`````````%D#```28````````````````````````+X"```1````````````
M`````````````#0#```1`````````````````````````&D"```28```````
M`````````````````"$#```28````````````````````````#8#```1````
M`````````````````````+(````28````````````````````````!D#```2
M8````````````````````````&\!```28````````````````````````+L`
M```B`````````````````````````,H````@````````````````````````
M`.`````28````````````````````````.0"```28```````````````````
M`````%4"```28````````````````````````.4````28```````````````
M`````````.L````@`````````````````````````*`"```28```````````
M``````````````4!```28````````````````````````(\!```28```````
M``````````````````H!```28````````````````````````(4"```28```
M`````````````````````'X!```28````````````````````````!`!```2
M`````````````````````````"$!```28````````````````````````!,"
M```28````````````````````````'4````28```````````````````````
M`"0"```28````````````````````````%X"```28```````````````````
M`````!(#```28````````````````````````"<!```2````````````````
M``````````H#```28````````````````````````#L!```2````````````
M``````````````X"```28````````````````````````,T!```28```````
M`````````````````$(!```2`````````````````````````$D!```2````
M`````````````````````#,#```A`````````````````````````%H!```2
M`````````````````````````"X#```28`@`8"````````"<`@```````-\!
M```28`D`G%L````````0`````````)L#```28`@`Y$H```````#$"0``````
M`"D$```28`@`D%@```````"8`````````'@#```28`@`M$,````````8````
M`````*H#```28`<`>!@````````0`````````+X#```28`@`J%0```````#H
M`P```````!<$```28`@`S$,````````0`@```````.L#```0`!,`>``"````
M`````````````(D#```28`@`($H```````#$`````````*@#```28`@``$(`
M``````!D`````````+`#```28`@`/$D```````",`````````-X#```2``@`
MW$4````````X`````````"0$```0`!,`X!`"`````````````````#X#```2
M8`@`*",```````!,`````````/<#```28`@`%$8```````!@`0```````-0#
M```1`!(`<``"```````(`````````!`$```0`!(`>``"````````````````
M`/`#```2``@`_"(``````````````````$<#```28`@`R$D```````!8````
M`````&(#```28`@`W$(```````#8``````````,$```28`@`=$<```````#(
M`0````````!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`86-C
M97-S`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C
M;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D
M:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T
M<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE
M7VEN9F\`97AI=`!C;&]S90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E
M860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P
M96-I9FEC`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`
M4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K
M`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W
M<F%P`&QI8F,N;75S;"UP<&,V-&QE+G-O+C$`9G!R:6YT9@!S=')D=7``<'1H
M<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?
M;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7W-T87)T7V,`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C
M=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS
M7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`;7E?
M<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!P87)?9&ER;F%M90!P
M87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!?96YD`'!A<E]C;&5A
M;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%```````````"````
M```6`````````````@``````$``"```````6`````````*I>````````&``"
M```````6`````````/5;````````*``"```````6`````````-9<````````
M,``"```````6`````````,]<````````.``"```````6`````````)Y>````
M````0``"```````6`````````.Q<````````2``"```````6`````````*9>
M````````6``"```````6`````````)!>````````8``"```````6````````
M`)5>````````<``"```````6`````````*]>````````"/\!```````F````
M'@``````````````$/\!```````F````-@``````````````&/\!```````F
M````,```````````````(/\!```````F````#0``````````````*/\!````
M```F````,0``````````````,/\!```````F````+```````````````./\!
M```````F````(@``````````````0/\!```````F````.P``````````````
M2/\!```````F````!0``````````````4/\!```````F````00``````````
M````6/\!```````F````/```````````````8/\!```````F````!@``````
M````````:/\!```````F````*```````````````&/T!```````5`````P``
M````````````(/T!```````5````!```````````````*/T!```````5````
M!P``````````````,/T!```````5````"```````````````./T!```````5
M````"0``````````````0/T!```````5````"@``````````````2/T!````
M```5````"P``````````````4/T!```````5````#```````````````6/T!
M```````5````#0``````````````8/T!```````5````#P``````````````
M:/T!```````5````$```````````````</T!```````5````$0``````````
M````>/T!```````5````$@``````````````@/T!```````5````$P``````
M````````B/T!```````5````%```````````````D/T!```````5````%0``
M````````````F/T!```````5````%@``````````````H/T!```````5````
M%P``````````````J/T!```````5````&```````````````L/T!```````5
M````&0``````````````N/T!```````5````&@``````````````P/T!````
M```5````&P``````````````R/T!```````5````'```````````````T/T!
M```````5````'0``````````````V/T!```````5````'P``````````````
MX/T!```````5````(```````````````Z/T!```````5````(0``````````
M````\/T!```````5````(P``````````````^/T!```````5````)```````
M`````````/X!```````5````)0``````````````"/X!```````5````)@``
M````````````$/X!```````5````)P``````````````&/X!```````5````
M*@``````````````(/X!```````5````*P``````````````*/X!```````5
M````+0``````````````,/X!```````5````+@``````````````./X!````
M```5````+P``````````````0/X!```````5````,```````````````2/X!
M```````5````,0``````````````4/X!```````5````,@``````````````
M6/X!```````5````,P``````````````8/X!```````5````-```````````
M````:/X!```````5````-0``````````````</X!```````5````-P``````
M````````>/X!```````5````.```````````````@/X!```````5````.0``
M````````````B/X!```````5````.@``````````````D/X!```````5````
M/0``````````````F/X!```````5````/@``````````````H/X!```````5
M````/P``````````````J/X!```````5````0```````````````L/X!````
M```5````0@``````````````N/X!```````5````0P``````````````P/X!
M```````5````1```````````````R/X!```````5````10``````````````
MT/X!```````5````1@``````````````V/X!```````5````1P``````````
M````X/X!```````5````2```````````````Z/X!```````5````20``````
M````````\/X!```````5````2@``````````````^/X!```````5````3```
M`````````````@!,/(AF0CBF`@A\$``!^.'_(?C=#`!(````8+5``$@```!@
M(``A.!```>BF`PA\(`"`3@``````````````````````````&`!!^/__@CUX
M?HSII@.)?2`$@$X````````````````8`$'X__^"/5A_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]T'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CUX?XSII@.)?2`$@$X````````````````8`$'X__^"/0A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(],'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CTH?HSII@.)?2`$@$X````````````````8`$'X__^"/4!^
MC.FF`XE](`2`3@```````````````!@`0?C__X(]H'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CVX?HSII@.)?2`$@$X````````````````8`$'X
M__^"/7!_C.FF`XE](`2`3@```````````````!@`0?C__X(]`'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CUH?HSII@.)?2`$@$X`````````````
M```8`$'X__^"/9A^C.FF`XE](`2`3@```````````````!@`0?C__X(]:'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CU(?HSII@.)?2`$@$X`````
M```````````8`$'X__^"/?A^C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]J'^,Z:8#B7T@!(!.````````````````&`!!^/__@CTX?HSII@.)?2`$
M@$X````````````````8`$'X__^"/5!^C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]2'^,Z:8#B7T@!(!.````````````````&`!!^/__@CWH?XSI
MI@.)?2`$@$X````````````````8`$'X__^"/>!^C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]Z'Z,Z:8#B7T@!(!.````````````````&`!!^/__
M@CT0?XSII@.)?2`$@$X````````````````8`$'X__^"/1A_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]T'Z,Z:8#B7T@!(!.````````````````
M&`!!^/__@CV0?XSII@.)?2`$@$X````````````````8`$'X__^"/=A^C.FF
M`XE](`2`3@```````````````!@`0?C__X(]D'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CW(?HSII@.)?2`$@$X````````````````8`$'X__^"
M/<A_C.FF`XE](`2`3@```````````````!@`0?C__X(]@'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CT@?HSII@.)?2`$@$X````````````````8
M`$'X__^"/<!_C.FF`XE](`2`3@```````````````!@`0?C__X(]\'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CTH?XSII@.)?2`$@$X`````````
M```````8`$'X__^"/?!_C.FF`XE](`2`3@```````````````!@`0?C__X(]
M0'^,Z:8#B7T@!(!.````````````````&`!!^/__@CT@?XSII@.)?2`$@$X`
M```````````````8`$'X__^"/3!_C.FF`XE](`2`3@```````````````!@`
M0?C__X(]@'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CWX?XSII@.)
M?2`$@$X````````````````8`$'X__^"/8A_C.FF`XE](`2`3@``````````
M`````!@`0?C__X(].'^,Z:8#B7T@!(!.````````````````&`!!^/__@CV(
M?HSII@.)?2`$@$X````````````````8`$'X__^"/>!_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]N'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CW8?XSII@.)?2`$@$X````````````````8`$'X__^"/:A^C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]6'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CT8?HSII@.)?2`$@$X````````````````8`$'X__^"/:!^
MC.FF`XE](`2`3@```````````````!@`0?C__X(]L'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CW`?HSII@.)?2`$@$X````````````````8`$'X
M__^"/9A_C.FF`XE](`2`3@```````````````!@`0?C__X(]8'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CU0?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/6!^C.FF`XE](`2`3@```````````````!@`0?C__X(]L'Z,
MZ:8#B7T@!(!.````````````````&`!!^/__@CUP?HSII@.)?2`$@$X`````
M```````````"`$P\H%Y".*8""'SP_\'[^/_A^Q```?AQ_R'X<`"!^&@`H?AP
M`($X:`"A.'P`89!\`&$XK?W_2Q@`0>@```!@4("BZ````&!8@&+H>"ND?#']
M_TL8`$'H````8&"`(ND```!@.(#BZP``R8L``)XO0`">0$W\_TL8`$'H````
M8```HR_8D6+X$`">0`$`8#CQ_O]+&`!!Z,G[_TL8`$'H``!_@/W[_TL8`$'H
ML0K#FP``?X#M^_]+&`!!Z(H&(XD"`"EAB@8CF0``?X#5^_]+&`!!Z(H&(XD!
M`"EAB@8CF7P`88#__R`YP``I>04`8SBT!V-\0$BC?QP`G4````!@:(""Z/[_
M8CP[W6,XM?G_2Q@`0>@D'V-XB?C_2Q@`0>A^`*'H<`#AZ````&````!@````
M.<B18OAX&V9\```GZ0``A2\``"/Y_O\B/8K?*3D(`"/Y````8'"!(ND0`"/Y
M_O\B/8W?*3D8`"/Y!``@.<"1(I'__R4Y(``I>0$`*3D(`)U!`0`@.0$`*2P!
M``@Y__\I.=P`@D`$`"4Y``!`.0```&#8D6+HM`<I?0,`I3@D'REY_O^"/!1*
M)GT``.`XM`>E?&3#A#CX_TGY5?W_2Q@`0>AY&W]\&`""0````&#8D6+H??W_
M2Q@`0>AX&W]\````8-B18NB)^?]+&`!!Z/[_8CR)W6,X41H`2```HR\\`)Y`
M````8-"1(ND``*DO&`">0/[_8CP^W6,X+1H`2````&#0D6+X````8-"18N@`
M`*,O"`">0?$U`$@```!@V)%BZ`W\_TL8`$'HQ?;_2Q@`0>B0`"$X>/OC?X@W
M`$@D'PIY*E"'?`0`2#FT!TI])!]*>1121GWX_XKX_/[_2P`````````!@`(`
M``(`3#P$7$(X*`",@!1BA'QX"R-\Y`8A>````#CA_P'XI@,(?!$``$A,V`$`
M`@!,/-A;0CBF`@A\"`"C./[_XCR<W.<X_O_"/'B9QC@````Y$``!^.'_(?@"
M`(/H_O]B/&"A8SA!^O]+&`!!Z``````````!@````````&````!@````8`(`
M3#R`6T(X````8````&!X@6(X>($B.0`8J7\@`)Y-````8`B`(ND``*DO(`">
M3:8""'QX2RQ]I@,I?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF`PA\
M(`"`3@(`3#P@6T(X````8````&!X@6(X>(&".%`@@WQT'H1\=`Z$?)4!A'P@
M`()-````8!"`(ND``*DO(`">3:8""'QX2RQ]I@,I?1```?CA_R'X&`!!^"$$
M@$X8`$'H(``A.!```>BF`PA\(`"`3@``0F`"`$P\L%I".````&!X@2*)``")
M+R``GDRF`@A\````8!B`(NGH_Z'[\/_!^P``J2\0``'XP?\A^!@`0?@4`)Y!
M````8`"!8NCI^/]+&`!!Z/__0CW__\(_````8("!(NE`?$HY.'S>.U!0WG__
M_Z(_=![>?SA\O3O__]X[0/"I?T``G$`X`.'[````8("!XCL!`"DY)!\J>0``
M/_DJ4#U]I@,I?7A++'TA!(!.&`!!Z```/^E`\*E_V/^<03@`X>MY_O]+````
M8""`(ND``*DO%`">0?[_8CSP'&,XU?G_2Q@`0>A``"$X`0`@.0```&`0``'H
MZ/^AZ_#_P>MX@2*9I@,(?"``@$X```!@``!"8`(`3#R@64(X````8"B`(ND`
M`*DO/`">0:8""'P```!@_O]B/(B!@CCP'&,X$``!^.'_(?BM]?]+&`!!Z"``
M(3@0``'HI@,(?$#^_TL``$)@./[_2P(`3#Q,64(XI@((?#@`PS@--`!(`?TA
M^/"/+>FH`B'Y```@.0@`(#FF`RE]*``!.0``1NDL-"!]$``(.0@`QCCP_RCY
M(,))>2(`1WDN!"E5($9*>7A3*7THP.IX>%,I?1Y"YU1X.RE]^/\H^<3_`$)`
M`"`Y(``!.:8#*7UP`"CI2`#HZ!@`2.EX.BE]>%(I?0D`2.EX4BE]I`\J><(/
M*7EX2TE](``I>8``*/G0_P!"``"#Z2```^@0`(/H&`!CZ0@`H^@X`,'KPBZ)
M>:0NBGEX2TI]*``AZ8+PJ'@@`$IY@EK>/YEYWCN"6BD]%"+>?YEY*3D4`BE]
M%$I*?7A:B7PX*"E]>%HI?11*2GUD\*EX>$,I?3```>D@`$IY(``_><(N1GEX
M^H=\@EH(/3A@YWR9>0@Y>"+G?!1:"'T40N=\*"A(>7@S"'V"\(9Y%$+G?&3P
MB'EX,PA](`#G>'A"*7W"+OUX.%`I?2``!GEX^BE]%/(I?2@H_GAXZ]Y_%/(I
M?63P7GF"\$IY(``I>7A3RG]``,'K>%((?2``77DX.`A]@EK>/W@R"'V9>=X[
M%/K^?\(N/GD4^@A]*"@_>7CS_W\4^@A]9/#_>(+PYW@@``AY>#OG?T@`X>MX
M.DI](`#^>#A(2GV"6O\_>.I*?9EY_SL4,M]\PBX?>10R2GTH*`9Y>/O&?!0R
M2GUD\"9Y@O`I>2``2GEX2\9\>#+I?%``X>@@`-]X.$`I?7CR*7V"6N<\F7GG
M.!3JIW\H*$=Y%.HI?<(N77EXZ^=\%#HI?63P!WF"\`AY(``I>7A#YWQX.LA\
M6`#!Z"``_7@X4`A]>/H(?8):QCR9><8X%/+&?R@H)GD4\@A]PBX^>7CSQGP4
M,@A]9/!&>8+P2GD@``AY>%/&?'@RZGQ@`.'H(`#>>#A(2GUXZDI]@EKG/)EY
MYS@4^N=_*"@'>13Z2GW"+A]Y>/OG?!0Z2GUD\"=Y@O`I>2``2GEX2^=\>#K)
M?&@`P>@@`/]X.$`I?7CR*7V"6L8\F7G&.!3JIG\H*$9Y%.HI?<(N77EXZ\9\
M%#(I?63P!GF"\`AY(``I>7A#QGQX,NA\<`#AZ"``W7@X4`A]>/H(?8):YSR9
M>><X%/+'?R@H)WD4\@A]PBX^>7CSYWP4.@A]9/!'>8+P2GD@``AY>%/G?'@Z
MRGQX`,'H(`#^>#A(2GUXZDI]@EK&/)EYQC@4^N9_*"@&>13Z2GW"+A]Y>/O&
M?!0R2GUD\"9Y@O`I>2``2GEX2\9\>#+I?(``X>@@`-]X.$`I?7CR*7V"6N<\
MF7GG.!3JIW\H*$=Y%.HI?<(N77EXZ^=\%#HI?63P!WF"\`AY(``I>7A#YWQX
M.LA\B`#!Z"``_7@X4`A]>/H(?8):QCR9><8X%/+&?R@H)GD4\@A]PBX^>7CS
MQGP4,@A]9/!&>8+P2GD@``AY>%/&?'@RZGR0`.'H(`#>>#A(2GUXZDI]@EKG
M/)EYYS@4^N=_*"@'>13Z2GW"+A]Y>/OG?!0Z2GUD\"=Y@O`I>2``2GEX2^=\
M>#K)?)@`P>@@`/]X.$`I?7CR*7V"6L8\F7G&.!3JIG\H*$9Y%.HI?<(N77EX
MZ\9\%#(I?63P!GF"\`AY(``I>7A#QGQX,NA\H`#AZ"``W7@X4`A]>/H(?8):
MYSR9>><X%/+'?R@H)WD4\@A]PBX^>7CSYWP4.@A]9/!'>8+P2GD@``AY>%/G
M?'@ZRGRH`,'H(`#^>#A(2GUXZDI]@EK&/)EYQC@4^N9_*"@&>13Z2GW"+A]Y
M>/O&?!0R2GUD\"9Y@O`I>2``2GEX2\9\PBY?>7@RZ7RP`.'H(`#<>#A`*7UX
M\BE]@EKG/)EYYS@4ZJ=_*"A'>7C[YWP4ZBE]%#HI?63P!WF"\`AY(``I>7A#
MZ'S"+C]Y>$+'?+@`P>AD\%UY.%#G?(+P2GEXXN=\>%.J?]``H>N"6L8\(``;
M>9EYQCAX4@A]%/+&?R@H)GEX^\9\%/+G?!0RYWS``,'H.$@(?2``^GAXV@A]
MPBY?>]INO3^"6L8\H>N].YEYQC@4XH9_*"A&>Q3B"'UD\#QY@O`I>7C[QGQX
M2YQ_%#((?7CB1GT@`!EY>#K'?,@`P>C"+BE[*"@^>R``YWAX2]Y_9/!?>]IN
MQCR"\%I[H>O&.'C3^G\4VL9\>-*)?Q0RYWP@`$IY%/+G?'A"*'W8`,'K(`#[
M>!12O7_"+FE[*"A_>WA+_W\@``AY9/`I>X+P.7MXRSE]%$(=?7C*27\4^@A]
MX`#AZ]INWC\@`!=Y(`"<>W@Z)WVAZ]X[PB[J>A3BWG\@`.=X*"CI>A0ZWG]X
M4RE]9/!X>X+P>WL42MY_>-L8?R``W7MXPBE_*"BF>WA"*'W:;O\_PBZI>R``
M6GMX2\9\H>O_.^@`(>D4TO]_(``(>63P^WJ"\/=Z>+M[?Q1"_W]XV@I_%#+_
M?_``P>C:;BD](`#Z>R``.7MX\EY]H>LI.<(N2'L4RBE](`#>>R@H2GL4\BE]
M>$-*?63PO'N"\+U[%%(I?7CKG'\@`#=Y>.)J?R@HYWIX^E]]PB[J>GA3YWS:
M;L8\^`!!Z2``&'MD\%U[H>O&.(+P6GMXT[U_%,+&?"``_WMXZHA_%/K&?-IN
M2CT4.L9\(`![>P`!X>AX2@E]H>M*.2``V7@4VDI](``I>2@H*'L42DI]9/#^
M>L(N*7N"\/=Z>+O>?WA+"'T40DI]>/*I?]INYSP@`%IY(`"<>W@R)GVAZ^<X
MPBY(>Q3BYWP@`,9X*"A)>Q0RYWQX0RE]9/`_>P@!`>F"\#E[%$KG?'C+_W\@
M`/AX>/K)?R@H!GMX4BI]PBX)>WA+QGS:;@@]$`$AZ2``O7MD\%M[H>L(.8+P
M6GMXTWM_%.H(?2``2GG:;BD]%%((?7C:ZG\4,@A](`#>>Q@!P>AX.D=]H>LI
M.2``&7D4\BE](`#G>"@H*GL4.BE]PBXG>W@[2GUD\!Q[@O`8>Q12*7UXPYQ_
M(``Z>7CB:G\H*$=[>$)(?<(N2GMX4^=\VF[&/"`!0>D@`/][9/`]>Z'KQCB"
M\#E[>,N]?Q3ZQGP@``AYVFY*/11"QGQXZHA_%#K&?"``>WLH`>'H>$H)?:'K
M2CD@`-AX%-I*?2``*7DH*`A[%$I*?63P7GO"+@E[@O!:>WC3WG]X2PA]%$)*
M?7CRJ7_:;N<\(`!9>2``G'MX,B9]H>OG.,(N*'L4XN=\(`#&>"@H*7L4,N=\
M>$,I?63P'WLP`0'I@O`8>Q1*YWQXP_]_(`#Z>'CZR7\H*$9[>%(J?<(N27MX
M2\9\VFX(/3@!(>D@`+U[9/`[>Z'K"#F"\#E[>,M[?Q3J"'T@`$IYVFXI/112
M"'UXVNI_%#((?2``WGM``<'H>#I'?:'K*3D@`!AY%/(I?2``YW@H*`I[%#HI
M?<(N!WMX.TI]9/!<>X+P6GL44BE]>-.<?R``.7EXXFI_*"@G>WA"2'W"+BI[
M>%/G?-INQCQ(`4'I(`#_>V3P'7NAZ\8X@O`8>WC#O7\4^L9\(``(>=IN2CT4
M0L9\>.J(?Q0ZQGP@`'M[4`'AZ'A*"7VAZTHY(`#:>!3:2GT@`"EY*"A(>Q1*
M2GW"+DE[>$L(?63P/GN"\#E[%$)*?7C+WG\@`%MY>/*I?\(N:'MX,B9]VF[G
M/"@H:7L@`)Q[>$,I?:'KYSA8`0'I%.+G?"``QGAD\%][@O!:>WC3_W\4,N=\
M%$KG?-IN"#UX^LE_(`"]>WA2*GVAZP@Y(`#\>!3J"'T@`$IY*"B)>Q12"'W"
M+HI[>%,I?63P:GL42@A]8`$AZ8+P>WMXVTI](`#>>WA2YG\@``AYVFXI/7@Z
MQWRAZRDY(`#G>!3R*7W"+@9Y%#HI?2@H!WEX,^=\9/"&>X+PG'L@`%UY>./&
M?!0Z*7UH`8'K(`#>>'@S1WTX0.=\./"J?WA3YWP;CT`]W+Q*82``_WL@`$IY
M(``I>13BBG\4^OQ_PBX\>13ZYWPH*#]Y>./_?Q3ZYWQD\!]Y@O`(>2``YWAX
M0_]_(`#\>WC[R'PX2`A]..#&?W@S"'UP`<'H%#+*?!3JIG\H*.9X%.H(?<(N
M_7AXZ\9\%#((?63P)GF"\"EY(``(>7A+QGP@`-UX>#/I?S@X*7TXZ)]_>/LI
M?7@!X>L4^NI_%/+??R@H'WD4\BE]PBX>>7CS_W\4^BE]9/#_>(+PYW@@`"EY
M>#OG?R``_GAX.\9\./"_?SA`QGQX^\9\@`'AZQ3ZZG\4XI]_*"@_>13BQGS"
M+CQY>./_?Q3ZQGQD\!]Y@O`(>2``QGAX0^A_(``?>7A#YWPX^-Q_.$CG?'CC
MYWR(`8'K%.**?Q3JO'_"+MQX%.KG?"@HW7AXX[U_%.KG?&3P/7F"\"EY(`#G
M>'A+J7\@`#MY>$L(?3C8_7\X,`A]>.L(?9`!H>L4ZJI_%/+=?\(N_7@4\@A]
M*"C^>'CKWG\4\@A]9/#>>(+PQG@@``AY>#/>?R``W7MX\R9].#C&?#CH:7]X
M2\9\F`$AZ11**GT4^NE_*"@)>13ZQGS"+A]Y>/LI?63P_W@42L9\@O#G>*`!
M(>EX._]_(`#&>"``_'MX^\=_%$HJ?3C@OG\X0.=\%-II?WCSYWPH*,EXPB[>
M>!3:YWQX\RE]%$KG?&3P"7F"\`AY(`#G>'A#*7T@`#YY>$OH?S@P"'TX\)]_
M>/L(?:@!X>L4^NI_%.J_?R@H_W@4Z@A]PB[]>'CK_W\4^@A]9/#?>(+PQG@@
M``AY>#/_?R``_7MX^R9].#C&?#CHR7]X2\9\L`$AZ11**GT4XHE_*"@)>13B
MQGS"+AQY>.,I?11*QGQD\.EX@O#G>"``QGAX.RE](``\>7A+YW\X0.=\.."_
M?WC[YWRX`>'K%/KJ?Q3RWW\H*-]X%/+G?,(NWGAX\_]_%/KG?&3P'WF"\`AY
M(`#G>'A#_W\@`/Y[>/LH?3@P"'TX\(E_>$L(?<`!(>D42BI]%.JI?R@HZ7@4
MZ@A]PB[]>'CK*7T42@A]9/#)>(+PQG@@``AY>#,I?2``/7EX2^9_.#C&?#CH
MWW]X^\9\R`'AZQ3ZZG\4XI]_*"@?>13BQGS"+AQY>./_?Q3ZQGQD\/]X@O#G
M>"``QGAX._]_(`#\>WC[)WTX0.=\.."I?WA+YWS0`2'I%$HJ?13RR7\H*,EX
M%/+G?,(NWGAX\RE]%$KG?&3P"7F"\`AY(`#G>'A#*7T@`#YY>$OH?S@P"'TX
M\)]_>/L(?=@!X>L4^NI_%.J_?R@H_W@4Z@A]PB[]>'CK_W\4^@A]9/#?>(+P
MQG@@``AY>#/_?R``_7MX^R9].#C&?#CHR7]X2\9\X`$AZ11**GT4XHE_*"@)
M>13BQGS"+AQY>.,I?11*QGQD\.EX@O#G>"``QGAX.RE](``\>7A+YW\X0.=\
M.."_?WC[YWSH`>'K%/KJ?Q3RWW\H*-]X%/+G?,(NWGAX\_]_%/KG?&3P'WF"
M\`AY(`#G>'A#_W\@`/Y[>/LH?3@P"'TX\(E_>$L(??`!(>D42BI]%.JI?R@H
MZ7@4Z@A]PB[]>'CK*7T42@A]9/#)>(+PQG@@``AY>#,F?2``W7AX,^E_.#@I
M?3CHWW]X^RE]^`'AZQ3ZZG\4XI]_*"@?>13B*7W"+AQY>./_?Q3Z*7UD\/]X
M@O#G>"``.WEX.^=_(`#\>'@[QGPXX+]_.$#&?'C[QGP``N'K%/I*?<(N?WL4
M\DI]9/`>>8+P"'D44D9]>$/(?R@H9GL8`L'K>/O&?'A"YWP4,DI]>$KG?`@"
MP>ABRB`](`!8>=;!*6'"+A][(``I>2``YW@4,LE\9/`9>Q3JIG\H*`9[>/O&
M?!3JYWP4,N=\9/!_>Q`"P>B"\'M[(`#W>'C;^W^"\!A[>-H=?10RR7QX4JI_
M%.*&?R@H_WK"+N9Z(`!*>7C#.7]X,_]_%.)*?13RR7\@``AY%/I*?11"WG\@
M`N'K>,IH?R``77EX.@=]9/#Z>H+P]WK"+JA[>+M:?R@HIGL@`.=X>$/&?!0Z
M_GQXTBA_%#+G?!3ZZ7\H`L'H(`![>WA2"GT@`/YX%-K_?R``2GDH*,A[%%+_
M?\(NRGMX4PA]9/"\>X+PO7L40O]_>.N<?R``]WMXXDI_PB[H>A0RR7P@`#E[
M>#I'?2@HZGIX0TI]%,K&?#`"`>D@`.=X9/#=>X+PWGL4.L9\>/.]?Q12QGQX
MZHI_(`#8>!1""7T@`%I[>/I??132"'W"+@I[(`#_>R@H!WL4^@A]>%/G?&3P
M_GHX`D'I@O#W>A0Z"'UXN]Y_(``;>7CRIW\H*'][>#+F?,(N9WMX._]_%%))
M?4`"X>@@`)Q[9/`9>X+P&'L4XDI]>,,Y?R``QG@4,DI]>,K&?Q3Z2GT4.NE\
M2`+AZR``O7MX0LA\(`!<>13JYWP@``AY9/!Z>X+P>WL40N=\>-M:?\(NB'LH
M*(9[%/KI?WA#QGQXTBA_%#+G?"``WGM0`L'H>%(*?2``_7@4\O]_(`!*>112
M_W\H**A[PBZJ>V3PFWMX4PA]@O"<>WCC>W\40O]_(`#V>WC:2G_"+LAZ%#+)
M?"``.7MX.D=]*"C*>A3*QGQX0TI](`#G>%@"`>ED\+Q[@O"]>WCKG'\4.L9\
M%%+&?'CB:G\@`-=X%$()?2``6GMX^E]]%-((?<(NZGH@`/][*"CG>GA3YWP4
M^@A]8`)!Z63PW7J"\-9Z>+.]?Q0Z"'T@`!AY>.J'?W@RYGPH*!Y[PBX'>Q12
M27UX.]Y_(`![>V@"X>AD\/EZ@O#W>GB[.7\4VDI](`#&>!0ZZ7P4,DI]>,JF
M?Q3R2GT@`)Q[<`+!ZWA"R'P@`%9Y%.+G?"``"'ED\!I[@O`8>WC#6G\40N=\
M*"C?>L(NR'IX0_]_>-(H?Q3ZYWP4\LE_>`+AZR``O7MX4@I](`#W>!3JWG\@
M`$IY*"CH>A12WG]D\-MZPB[J>H+PUGIX4PA]>+-[?WC:2G\40MY_@`(!Z2``
MV'L4^NE_(``Y>W@Z1WT4RO]_PBX*>R``YW@H*`9[9/#\>H+P]WIX4\9\>+N<
M?Q0Z_W]XXFI_%#+_?Q1""7V(`L'H(`#Y>R``6GMX\EY]%-((?<(N*GL@`-Y[
M*"@G>Q3R"'UX4^=\9/`=>X+P&'L4.@A]>,.]?R``&GEXZHI_PBY'>Q0RR7P@
M`'M[>/I??2@H2GMX.TI]%-K&?)`"X>@@`/][9/`^>X+P.7L4^L9\>,O>?Q12
MQGQX\JI_%#KI?"``G'MX0DA](`#;>!3BYWR@`H'K(``(>2@H:GL40N=\PBYH
M>WA#2GUD\%][%%+G?)@"0>F"\%I[>-/_?R``O7L@`.AX%`(??!1227T4XBE]
M%.I*?7CZW7]X,J9_PBX=>2``QG@@`-Y[%#)*?2@H!GEXZ\9\%/(I?10R2GUD
M\&9[@O![>R``2GEXV\9\@O`=>7@R_G\H\`AY>#K'?\(N7GD@`.=X>.L(?10Z
M*7TH*$=Y>//G?!12I7P4.BE]%"*(?!1B*7T46F9](``I>2``I7@@`(1X(`!K
M>2```'@``"/Y"`"C^!``@_@8`&/Y(``#^*@"(>GPCTWI>5(I?0``0#D,`()!
MG>'_2Q@`0>@``R$X4!X`2``````````!@`H```(`3#P@0T(XI@((?/4=`$AY
M&WQ\L?\A^```P#L@`()!````8#"`(ND``,`[>..%?P``J>L``+TO'`">0%``
M(3AX\\-_#!X`2#T`B2L4`)Y!`0"E.```)8D``*DO[/^>0%`HO'QX(YI\M`>_
M?'CKNW\``-OK``"^+\3_GD%X^^5_>..$?WCSPW]YW?]+&`!!Z```HR\H`)Y`
MKO@^?3T`B2\<`)Y`4-B]?P$`_SMT'KU_%/K>?P``NI.$__]+"`![.[#__TL`
M`````````8`&```"`$P\4$)".*8""'P0``'XD?\A^&0`@3CPCRWI:``A^0``
M(#D5__]+:``AZ?"/3>EY4BE]``!`.0P`@D%UX/]+&`!!Z'``(3@0``'HI@,(
M?"``@$X``````````8`````"`$P\\$%".*8""'SP_\'[^/_A^W@;?WP0``'X
M@?\A^/"/+>EH`"'Y```@.60`P3MX\\1_>/OC?Z'^_TL``*,O(`">0&@`(>GP
MCTWI>5(I?0``0#D\`()!^=__2Q@`0>AF`"'I)!\I>?C_23D```!@,(`BZ0``
M*>D44BE]$`!)Z0``JB\)`$GY]/^>0*3__TN``"$XL!P`2``````````!@`(`
M``(`3#Q,04(XI@((?!T<`$A1_R'X>!M_?'@CGGSPCRWI:``A^0``(#D``"2)
M/0")+P@`GD`!`,0[>//#?W'=_TL8`$'H9`"!.'@;?7QX^^-_Y?W_2WD;?'Q,
M`()!4=W_2Q@`0>A`Z*-_\`"<00``0#FN4#Y]``"I+ZY1/'T!`$HY\/^>0```
M8#AH`"'I\(]-Z7E2*7T``$`Y=`&"01'?_TL8`$'H````8#"`8NL``"`Y``!;
MZ_C_&CFT!SQ]`0`I.20?*GDJ4$A]``"J+^S_GD````!@N($B@0(`G#BT!X1\
M)!^$>```B2\D`)Y!>--#?[W:_TL8`$'H``"C+P``>_A``)Y`__]@.(#__TL!
M`"`Y````8'@C@WRX@2*1$>#_2Q@`0>AY&WE\W/^"020?A7MXTT1_.>'_2Q@`
M0>@``#O[`0`\.0``6^D````Y)!\I>2I)"GUD`(&3>/OI?P``28D``*HO#`">
M03T`BBN0`)Y`9@"!ZP```&`P@&+K4$@_?0(`?3BT!RE]%$IC?```6^N=W_]+
M&`!!Z"0?G'L``*,O*N%Z?&#_GD%F`"'I``!;Z?___SLD'REY*DA*?0$`/XT!
M``HY``"I+P``*ID,`)Y!/0")*S``GD`]`"`Y```JF0``0#FN4#Y]``"I+ZY1
M*'T!`$HY\/^>0(S^_TL!`"DY7/__2WA#"GVT__]+L``A.&@:`$@`````````
M`8`'```"`$P\+#]".*8""'SY&0!(P?XA^'D;?7SPCRWI^``A^0``(#EH`()!
M```]B0``B2]<`)Y!&=__2Q@`0>AY&WQ\3`""0?[_8C_^_T(__O\B/_7<>SOT
MW%H[]]PY.V@``3MXXX-_B=C_2Q@`0>AY&W]\.`""0'CC@W^UV_]+&`!!Z'CK
MHW_)W?]+&`!!Z/@`(>GPCTWI>5(I?0``0#G4`()![=S_2Q@`0>@3`/\[>-MD
M?WC[XW^YW_]+&`!!Z```HR^@_YY!>--$?WC[XW^AW_]+&`!!Z```HR^(_YY!
M>.NC?ZW:_TL8`$'H>!M^?'C[XW^=VO]+&`!!Z!3R8WP"`&,XM`=C?`G>_TL8
M`$'H>/OF?WCKI7]XRR1_>!M^?+';_TL8`$'H>,,$?WCSPW_AV?]+&`!!Z/__
M@R]X\\-_*`">08``(8$F!"E5`$")+Q@`GD"Y_O]+>//#?Y78_TL8`$'H`/__
M2PG>_TL8`$'HZ/__2T`!(3C@&`!(``````````&`"````@!,/*@]0CBF`@A\
M^/_A^W@;?WP0``'X,?\A^"@`@3CPCRWIN``A^0``(#G]VO]+&`!!Z```(RQ4
M`()`0``A@28$*54`0(DK$`">0?__*FT`H(HO'`">0`(`@#AX^^-_Z=?_2Q@`
M0>@T`&-\?MEC5+@`(>GPCTWI>5(I?0``0#D4`()!A=O_2Q@`0>@``&`XX/__
M2]``(3AH&`!(``````````&``0```@!,/``]0CBF`@A\````8#B`(ND0``'X
MX?\A^```:8#AVO]+&`!!Z````&!`@*+H_O_"//[_@CS(W,8X_=R$."'=_TL8
M`$'H(``A.!```>BF`PA\(`"`3@`````````!@`````(`3#R</$(XI@((?/C_
MX?L```!@.(#BZQ```?C1_R'X``!_@'G:_TL8`$'H>?__2P``?X!IVO]+&`!!
MZ/[_XCS^_Z(\B=_G./[_@CP````Y>#OF?*C5I3@9W80XX=?_2Q@`0>@P`"$X
MC!<`2``````````!@`$```(`3#PD/$(XI@((?`47`$AAWR'X``#`._"/+>EX
M("'Y```@.4'7_TL8`$'H:`#A._[_PCS^_X(\>!ME?"[=QC@RW80X>/OC?W`0
MH3MYV?]+&`!!Z'C[XW\`$*`X>.ND?P7:_TL8`$'HM`=_?```GR\T`)Q!`0!_
M.+0'8WR)V_]+&`!!Z'D;?GP<`()!>/OE?WCKI'^1U?]+&`!!Z```(#FN^3Y]
M>"`AZ?"/3>EY4BE]``!`.7CSPW\,`()!R=G_2Q@`0>B@("$XF!8`2```````
M```!@`,```(`3#Q,.T(X*/__2P````````````````(`3#PT.T(XI@((?":`
MD'T(`(&1Z14`2*'N(?AX&WY\_O]B/#[=8SAX(Y]\\(\MZ?@0(?D``"`YM?C_
M2R\`@#AX&WI\>//#?PW6_TL8`$'H``"C+S0`GD'^_V(\>//$?T?=8SB-^?]+
M^!`AZ?"/3>EY4BE]``!`.7CSPW]X`8)!%=G_2Q@`0>AX\\-__O^"/P77_TL8
M`$'H5-V<._[_(C]XXX1__O_B/K0'>WQX^^-_)=K_2Q@`0>C^_\(^``"`.@``
M.B[UW#D[>!M_?````#L!`'L[5MWW.C+>UCKX`*$[:`"A.@"`E&(``+\O;/^>
M00``/XD``(DO"`">0'C+/W\@`))!>/OD?WC30W]IV_]+&`!!Z'CCA'\``*,O
MR`">07C[XW]QUO]+&`!!Z+0'8WP4&C]]__\IB2\`B2^0`)Y!%!I[?/\/@R\0
M_YU!>//'?WB[YGYX^^5_>+/$?GCKHW]UU_]+&`!!Z'BKI'YXZZ-_I=7_2Q@`
M0>@``*,O8`">0(``(8$F!"E5`*")?U``GD`!`(`X>.NC?SW4_TL8`$'H``"C
M+S@`GD#^_V(\>.ND?T?=8S@]^/]+>.NC?[G6_TL8`$'H>!M^?*#^_TO__V,X
MM`=C?*X9'W]8__]+>..$?P``8#CQV/]+&`!!Z'@;?WSX_O]+8!$A.`@`@8$@
M@9!]3!0`2``````````#@`P``/__(SD!`$F)`0`).0``JB\@`)Y-+P"**P(`
M*3D(`)Y`>$LC?7A#"7W<__]+`````````````````@!,/.PX0CBF`@A\^/_A
M^WD;?WP0``'XT?\A^!``@D$``#^)``")+Q``GD#^_V(\]=QC.!`!`$@5U?]+
M&`!!Z/__(SD42K]\>!MI?!0:?WS__V,X0!B_?PP`G4'__[\O"`">0`$`(#D!
M`"DL__\I.;@`@D$``$6)+P"*+Y0`GD'__T4Y4"@_?4!0OW\(`)U``0`@.0``
M18G__P4Y+P"*+W@`GD#__T4Y4"@_?4!0OW\,`)U!__^_+P@`GD`!`"`Y`0`I
M+/__I3C__RDY$`""00``18DO`(HOZ/^>05`HOWP``&`X`@`E.0`0J2M@`)U!
M````8`$`I3C`@2(Y>/OD?WA+(WVIUO]+&`!!Z$```$C__Z4X5/__2P$`*2QX
M0P5]__\I.7#_@D!`*+]_>/^>0```/XG^_V(\5MUC."\`B2_L_IY!Z=3_2Q@`
M0>@P`"$X]!(`2``````````!@`$```(`3#R,-T(XI@((?`H`0#G^_V(\6-UC
M.%T2`$A1_R'X_O_"/_[_HC]YW=X[/MV]._[_XC_^_X(_E=W_.Y_=G#OPCRWI
MB``A^0``(#G^_R(]R-PI.9A6B7T:`$`YF%8)?)``03G0_R`YF$^*?>#_(#F8
M3PI\_O\B/?+<*:&``"&Q)?7_2_[_8CQAW6,X&?7_2_[_8CQIW6,X#?7_2_[_
M8CQRW6,X`?7_2WCSPW_Y]/]+_O]B/(G=8SCM]/]+>.NC?^7T_TMX^^-_W?3_
M2WCC@W_5]/]+_O]B/*G=8SC)]/]+_O]B/$?=8SB]]/]+_O]B/+/=8SA1]/]+
M>1MD?`P`@D%XXX-_1?7_2_[_8CS$W6,X-?3_2WD;9'P0`()!_O]B/-;=8S@E
M]?]+_O]B/.'=8S@5]/]+>1MD?#@`@D%XZZ-_"?7_2_[_@CQX\\-_#=Z$./GT
M_TN(`"'I\(]-Z7E2*7T``$`Y4`""0874_TL8`$'H_O]B//'=8SC-\_]+>1MD
M?`P`@D%X^^-_N/__2_[_@CP*`*`X`MZ$.'$`83C1T/]+&`!!Z```HR^<_YY`
M>P"!.-3__TNP`"$X#!$`2``````````!@`0```(`3#S$-4(X````8`B!(H'_
M_XDO8`">0*8""'S^_V(\E=UC.!```?BA_R'X4?/_2P``0#D``",L'`""00``
M(XD``*DO$`">03``*6G__TDQ$$E*?0```&!@`"$X"(%"D1```>@```!@I@,(
M?`J!8N@@`(!.````8`J!8N@@`(!.``````````&``````@!,/#@U0CBF`@A\
M$``!^.'_(?@EU/]+&`!!Z-W1_TL8`$'H```C+!P`@D$``"/I(``A.'A+(WT0
M``'HI@,(?"``@$X``"`YZ/__2P`````````!@`````(`3#S@-$(XI@((?+T/
M`$B!_R'X_O_"/W@;?WP/WMX[>//#?W7R_TMX^^1_>1M]?!``@D$``#V)``")
M+Q0`GD!X\\-_6?/_2X``(3C,#P!(,='_2Q@`0>@``*,O[/^>0'C[XW_=T/]+
M&`!!Z'@;?'QXZZ-_S=#_2Q@`0>@4&GQ\`@!C.#W4_TL8`$'H_O_"//[_@CPR
MWH0X>.NG?W@;?'Q4W<8X>/OE?]G1_TL8`$'H>..$?XS__TL``````````8`$
M```"`$P\'#1".*8""'P``"`YF($I80```#F@@0AAL0X`2/__`#S^_R(_P'T`
M8#[=.3MX&WA\>,LC?VH!(7P0`$$Y$`#A.!12*7T4.@A]\(]-Z0``2?D``$`Y
M````8`B!(CD(`$`YL('A.YA6"7S__T`]P'Y*89A7"'P```!@((%"Z0```#F@
M@0AA%#H(?=!^7_D@`$`YF%9I?3``0#F85HE]0`!`.9A6"7S__T`]\'Y*89A7
M:'T````Y$`!*.:"!"&$4.@A]F%>(?0```#D0`$HYH($(810Z"'V85PA\4`!`
M.9A6"7P``$`Y__\@/:"!2F'8?BEA%#I*?9A/"GP```!@:($BZ>A^/_G-\/]+
M>1M^?%0`@D$``#Z)``")+T@`GD$E_O]+>//#?S70_TL8`$'H>!M]?```(#D0
M`$$YF($I87CKHW\44BE]``!)Z?"/+>EY2DI]```@.5@(@D$AT?]+&`!!Z(G]
M_TO0?K\[>1M^?+@`@D%X\\-__O]B/P'/_TL8`$'H___>.R;>>SND#V-X`0!C
M.&G2_TL8`$'H>!M\?'@;?7P!`+Z,``"E+Y0`GD#H?M\["0"^ZP``O2\\`)Y!
M>.NC?Q'P_TMY&WU\Z/^"00``/8D``(DOW/^>0:'T_TL``*,OT/^>07CKHW]Q
MS_]+&`!!Z'@;?7RX?G\[?```2-7O_TMY&VE\(`""00``*8D``(DO%`">047/
M_TL8`$'H>1M^?%#_@D`)`'WH``"C+]#_GD#^_\(_'][>.SC__TMXZZ-_>-MD
M?W7/_TL8`$'H`@"].U#__TMX\\-_(?3_2P``HR\<`)Y!>//#?_'._TL8`$'H
M>!M]?```O2\<`)Y`"0#;ZP``OB_<`)Y!```^B0``B2_$_YY`>.NC?_[_0C_=
MS?]+&`!!Z%;=6CMX&WY\>..#?\G-_TL8`$'H%/+#?P0$WCNT!]Y_>//#?S'1
M_TL8`$'H_O_B//[_@CQXXXA_*][G.'C31G]XZZ5_,-Z$.'@;>WS)SO]+&`!!
MZ,`!@#AXVV-_N='_2Q@`0>C__X,O7`">0"G._TL8`$'H```C@1$`B2](`)Y!
M````8$B`XNL``-CK"<[_2Q@`0>C^_X(\>-MF?SG>A#@"`./H``!_Z'CSQ7^I
MRO]+&`!!Z```H#O4_?]+``"@.S#__TL@?Y\X>-MC?RG._TL8`$'H>1M\?"P`
M@D$```!@2(`BZ0``N.C^_X(\>-MF?W3>A#@``&GH7<K_2Q@`0>BT__]+.'\_
M@28$*54`0(DOS/^>0#Q_OX-=S_]+&`!!Z`#H@W^X_YY`.'\_@?X%*57``8DO
MJ/^>0'CSPW\9T/]+&`!!Z'@;?7S^_V(\&MYC.-WM_TL``*,OK`&>0```^.IX
MN^-^<<S_2Q@`0>BT!WY\`P">+X@`G4#\_WXX_O^"/,?>A#@4&G=\+='_2Q@`
M0>@``*,O:`">0`0`GB\<`)Y!_/_>.[0'WG\4\M=___\^B2\`B2](`)Y`"`#8
MZP``OB\\`)Y!>//#?PW,_TL8`$'H`P"C*R@`G4#\_V,X_O^"/,S>A#@4&GY\
MS=#_2Q@`0>@``*,O"`">0'CSUW^]^?]+``"C+U`$GD```(`X>+OC?N7+_TL8
M`$'H>1MX?#@$@D$"`*`X[O^`.$W0_TL8`$'H^'_?.P8`H#AX\\1_>,,#?U7)
M_TL8`$'H^'\_B0``B2_8`)Y`^7\_B4,`B2_,`)Y`^G\_B4$`B2_``)Y`^W\_
MB4,`B2^T`)Y`_'\_B4@`B2^H`)Y`_7\_B44`B2^<`)Y``@"@.,;_@#AXPP-_
MV<__2Q@`0>@I`*`X>//$?WC#`W_ER/]+&`!!Z/[_`CUX\\=_B=\(.?[_@CQX
MTT9_>-ME?]'>A#AXZZ-_/<S_2Q@`0>AXVV-_4<G_2Q@`0>AXZZ1_>,LC?SWM
M_TMXZZ-_H?G_2XS[_TL``-CKK<O_2Q@`0>AX&V1\>//#?S'S_TMY&W=\0/Z"
M0#C^_TL``*`X``"`.'C#`W___V`Z/<__2Q@`0>A%9R`]__]`/@$C*6'__R`^
M__\`/O__X#T@?S_YS>\@/?A_WSJ)JREA(`1S5B``*7E8?U)B:'\Q8GA_$&(H
M?S_YNI@@/8A_[V'^W"EA('^_.B``*7E8?Y\Z,'\_^3(0(#UV5"EA.'\_^=+#
M(#WPX2EA(``I>4!_/_D``"`Y2'\_^5!_/_F8?S^1>)ME?GBSQ'YXPP-_P<?_
M2Q@`0>BT!WY\``">+QP!G4%XPP-_6'_?.P7)_TL8`$'H2'\_.4A_O^B`_T`Y
M+$P`?U!_/SF^[J54+$S@?K0'J7P!`*4X.`"%+[0'HWRN25Y]%!I^?!@"G4!`
M`*4@``"`.+0'I7P@?Y\[E<K_2Q@`0>AXXX-_Y=/_2S@`H#@``(`X>//#?WG*
M_TL8`$'HD'__DI1_'Y,@?W\X_O\"/\A_GSL``,`[L'__.B;>&#NMT_]+('\_
M.2Q,('VP?S^1*'\_.2Q,('VT?S^1,'\_.2Q,('VX?S^1.'\_.2Q,('V\?S^1
M0'\_.2Q,('W`?S^1KO"W?'CC@W]XPP1_`0#>.P(`G#L]RO]+&`!!Z!0`OBO@
M_YY````@.?[_`CV)WP@YR'__./!_/YG(_?]+2']?Z20?R7L44BE](``I>4!(
MJG\0`)U`4']?Z0$`2CE0?U_YFG]_Z%!_7^E(?S_Y0A_)>P``HR\42BI]4'\_
M^?P`GD%``",A>//7?P!(GG\(`)U`>$LW?;0'_'YXL\1^>..%?Q0:='P-QO]+
M&`!!Z)A_/X$4NBE]0`")+YA_/Y%(_IY`4/#7?WBKHWZT!]Y_%.*6?YW2_TL0
M`.`Z(`#`.3``(#ET``!(F.9`?9A.''P0`$$Y>*NC?F@`(?D``"`YF+Y\?<#_
MWCN@@2EAF':<?;0'WG\44BE]0`"<.YB727T``"`YH($I8112*7V8CVE]```@
M.:"!*6$44BE]F(>)?0``(#F@@2EA%%(I?9A_"7PATO]+:``AZ3\`GB^,_YU!
M>//%?WCCA']XHX-^2<7_2Q@`0>B8?]^3D/W_2_A_GSM8__]+.`"E(```@#BT
M!Z5\#/[_2_[_@CS^_V(\#=Z$.)7=8SC-Z?]+_O_B/_[_PC^)W_\[[M[>.SW&
M_TL8`$'H_O^"/'C[Z']XTT9_>-ME?W@;9WS@WH0X>.NC?WG(_TL8`$'HP`&`
M.'CKHW]IR_]+&`!!Z/__@R\H_)Y`V<?_2Q@`0>@``".!$0")+Q3\GD#EQ?]+
M&`!!Z`$`G#MX^^E_M`><?WC31G]X&V=\>..(?WC;97]X\\1_>.NC?QG(_TL8
M`$'HH/__2P``(>AH!0!(``````````&`$@```@!,/%@J0CBF`@A\)04`2&'_
M(?@```!@.(#BZP``?X`YR/]+&`!!Z'@;?GP``'^`*<C_2Q@`0>BX`#Z)N0`C
MF?[_8CQYW6,XR>?_2P``(RP<`()!```CB3$`B2\0`)Y``0`CB0``B2\(`)Y!
M:?+_2P``?X````!@N(&B.]W'_TL8`$'H_O^"/`L`P#@!`*`X_]Z$.(7%_TL8
M`$'H```C+)0`@D```'^`L<?_2Q@`0>C^_X(\`P#`.`$`H#@$WX0X6<7_2Q@`
M0>AY&WY\<`&"0```?X"%Q_]+&`!!Z/[_@CP#`,`X`0"@.`O?A#@MQ?]+&`!!
MZ'D;?GS4`8)!_O]B/$?=8S@-Y_]+>1M\?(@!@D$``'^`1<?_2Q@`0>@0`#[I
M>..%?P``B>AQP_]+&`!!Z)P!`$@0`"/I(``@/P$`P#L`!#EC*`!IZP@0/8'_
M_YX[``!_@+0'G'\`\(E_*`"=0/G&_TL8`$'H``#`.'CCA7]XVV1_1<C_2Q@`
M0>AY&WI\(`""0````&#`D:*`__^E.`#@A7\0_YY``0#`.XP``$@0$%WI)!_)
M>RI("G\``%KI#``J@3A(*7\`!(DO*`">0!``BNAXPP-_T<G_2Q@`0>@``*,O
ML/^>0`$`WCNT!]Y_:/__2P``?X!QQO]+&`!!Z```FN@"`,`X``"@.-W'_TL8
M`$'H>!MD?+S__TM-QO]+&`!!Z'C;9'\!`-X[M`?>?QG&_TL8`$'H"!`]@0``
M?X``\(E_V/^=06S^_TL``'^`&<;_2Q@`0>@0`#[I_O^B/`;?I3@``(GH0<+_
M2Q@`0>@0`#[I```IZ0P`*8%``"EU8/Z"00``?X#AQ?]+&`!!Z!``/ND``(GH
M,</_2Q@`0>A`_O]+J>O_2WD;?'P``'^`T`""0;7%_TL8`$'H$``^Z7CCA7\`
M`(GHX<'_2Q@`0>AXXX-_5<+_2Q@`0>@``'^`B<7_2Q@`0>AX&WY\``!_@'G%
M_TL8`$'H_O^"/`$`H#@-WX0X9</_2Q@`0>C^_Z(\(M^E.'@;9'QX\\-_C<'_
M2Q@`0>@``'^`0<7_2Q@`0>@``"`YN0`CF?[_8CP^W6,XX>3_2P```&```*,O
MT)%B^$P`GD````!@R)%BZ/GR_TL```!@``"C+]"18O@P`)Y`_O]B/"C?8S@1
MP_]+&`!!Z.G$_TL8`$'H````8,B10ND0`#[I``"JZ)S]_TL```!@T)%BZ,`!
M@#AAQ_]+&`!!Z!$`@R]X&V9\+`">00$`(SD!`(DK(`"=0!`0/>D8$+WH_O]B
M/$G?8S@``(GHK<+_2Q@`0>B@`"$XJ`$`2``````````!@`@```(`3#QP)D(X
MI@((?/#_P?OX_^'[>!M^?!```?B1_R'X;>W_2RGM_TMX&W]\B?#_2P``HR]0
M`)Y!``"^+T@`GD$``#Z)``")+SP`GD'^_X(\>/OC?RO>A#BYPO]+&`!!Z``8
MOW\@`)Y`<``A.'CSPW\0``'H\/_!Z_C_X>NF`PA\S.;_2W``(3@\`0!(````
M``````&``@``````8````&````!@````8````&````!@`@!,/,`E0CC__R(]
M*'PIZ?C_X?O__^(_T?\A^#!\_SO__ZDO0`">0:8""'P8`$'X^/__.T```?@`
M``!@``!"8*8#*7UX2RQ](02`3A@`0>CY_S_I__^I+^C_GD!```'HI@,(?#``
M(3CX_^'K(`"`3G#_P?EX_^'Y@/\!^HC_(?J0_T'ZF/]A^J#_@?JH_Z'ZL/_!
M^KC_X?K`_P'[R/\A^]#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q```?@@`(!.
M</_!Z7C_X>F`_P'JB/\AZI#_0>J8_V'JH/^!ZJC_H>JP_\'JN/_AZL#_`>O(
M_R'KT/]!Z]C_8>O@_X'K$``!Z.C_H>NF`PA\\/_!Z_C_X>L@`(!.\/_!ZQ``
M`>CX_^'KI@,(?"``@$Z0H@$``````*8""'P%`)]"I@)H?1@`0?CP_TOHI@,(
M?%!@BWT46F)]T/\,.```B^F"\`!XI@.)?0@`:^D@!(!.R/__2\3__TO`__]+
MO/__2[C__TNT__]+L/__2ZS__TNH__]+I/__2Z#__TN<__]+F/__2Y3__TN0
M__]+C/__2XC__TN$__]+@/__2WS__TMX__]+=/__2W#__TML__]+:/__2V3_
M_TM@__]+7/__2UC__TM4__]+4/__2TS__TM(__]+1/__2T#__TL\__]+./__
M2S3__TLP__]++/__2RC__TLD__]+(/__2QS__TL8__]+%/__2Q#__TL,__]+
M"/__2P3__TL`__]+_/[_2_C^_TOT_O]+\/[_2^S^_TOH_O]+Y/[_2^#^_TO<
M_O]+V/[_2P(`3#QD(T(XI@((?!```?CA_R'XJ<C_2P```&`@`"$X$``!Z*8#
M"'P@`(!.<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@```N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!
M4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X
M`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E
M<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`
M,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`T-P!5;F%B;&4@=&\@8W)E871E
M(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`%53
M15(`55-%4DY!344`5$5-4$1)4@!435``+W1M<`!E=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`[
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U
M,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE
M(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R
M(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D
M;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D
M;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA
M<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E
M="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D
M:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F
M9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E
M="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0[
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M
M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@
M)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL
M97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R
M971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^
M>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M
M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE
M;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN
M;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E
M9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E
M=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA
M;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\[
M"FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM
M(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@
M(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN
M+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,
M12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@
M87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R
M:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA
M;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H
M95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N
M86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[
M7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@
M(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F
M:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S
M+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?
M0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M
M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T
M96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO
M<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET
M92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N
M=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG
M>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L
M:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=6
M7S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[
M4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?
M8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y]
M(#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH```$;`SO(````&````-Q]___@````?(7___`$``#0BO__#`$``/R@
M__]0`0``S*'__X@!```LHO__J`$``-"B___0`0``\*3__PP"``!TIO__2`(`
M`!RG__]P`@``@*?__Y`"``#XI___M`(``-"H___@`@``Z*C___0"``#XJO__
M1`,``#"K__]8`P``D*S__X`#``!8KO__L`,``.2N___0`P``/*____`#````
ML/__)`0``,2Y__^`!```K+W__[P$``",O___]````!```````````7I2``1X
M00$;#`$`$````!@```#T?/__H`<````````4````+````)"^__\L`0```$$)
M00!'!D%`````1````+R)__\L%@```$0)00!!E@J7"9@(F0>:!IL%G`2=`YX"
MGP$107Y!#H`&`X$%#@!!W][=W-O:V=C7U@9!`#0```"(````I)___]``````
M0PE!`$&:!IL%G`2=`YX"GP$107Y"#E!*"@X`0M_>W=S;V@9!"P``'````,``
M```\H/__8`````!%#G`107Y-#@!"!D$````D````X````'R@__^D`````$4)
M00">`I\!0PZ``1%!?ET.`$'?W@9!.`````@!``#XH/__(`(```!#"4$`09D'
MF@:;!9P$G0.>`I\!$4%^00ZP`0)_#@!!W][=W-O:V09!````.````$0!``#<
MHO__A`$```!#"4$`09@(F0>:!IL%G`2=`YX"GP$107Y!#L`"`E@.`$'?WMW<
MV]K9V`9!)````(`!```DI/__J`````!$"4$`GP%##M`!$4%^7PX`0=\&00``
M`!P```"H`0``I*3__V0`````1PX@$4%^3`X`0@9!````(````,@!``#HI/__
M>`````!$"4$`GP%$#C`107Y2#@!!WP9!*````.P!```\I?__V`````!#"4$`
M09T#G@*?`1%!?D$.H$%M#@!!W][=!D$0````&`(``.BE__\8`````````$P`
M```L`@``[*7__Q`"````10E!`!%(?T&4#)4+E@J7"9@(F0>:!IL%G`2=`YX"
MGP$107Y!#N`B`G<.`$/?WMW<V]K9V-?6U=0&009(````$````'P"``"LI___
M.``````````D````D`(``-"G__]@`0```$0)00"?`4,.,!%!?@)-#@!!WP9!
M````+````+@"```(J?__R`$```!&"4$`09P$G0.>`I\!$4%^00ZP`0)F#@!!
MW][=W`9!'````.@"``"@JO__C`````!+#F`107Y,#@!$!D$````<````"`,`
M``RK__]8`````$4.(!%!?D@*#@!#!D%!"S`````H`P``1*O__\0`````0PE!
M`$&<!)T#G@*?`1%!?D$.@`%."@X`0=_>W=P&00L```!8````7`,``-2K___$
M"0```$<)00!!CA*/$9`0D0^2#I,-E`R5"Y8*EPF8")D'F@:;!9P$G0.>`I\!
M$4%^1P[`A`(#7@(.`$'?WMW<V]K9V-?6U=33TM'0S\X&03@```"X`P``/+7_
M_^@#````0PE!`$&8")D'F@:;!9P$G0.>`I\!$4%^00Z@`0+Q#@!!W][=W-O:
MV=@&03````#T`P``Z+C__Y@`````10E!`)X"GP%##G`107Y3"@X`109!W]Y!
M"T$.`$'?W@9!```D````*`0``(2`__^<`@```$<.D`$107Z>`I\!`I,*#@!"
MW]X&00L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````/__________```````````!``````````$``````````0``````
M``#-`@````````\`````````-00````````,`````````'@8````````#0``
M``````"<6P```````/7^_V\`````(`(````````%`````````"@,````````
M!@````````#@`@````````H`````````4P0````````+`````````!@`````
M````%0````````````````````,`````````"/T!```````"`````````+@%
M````````%``````````'`````````!<`````````P!(```````````!P````
M`(A:`````````P``<`````````````````<`````````@!`````````(````
M`````$`"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````+````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````"J7@```````/5;````
M``````````````#67````````,]<````````GEX```````#L7````````*9>
M``````````````````"07@```````)5>``````````````````"O7@``````
M`$=#0SH@*$%L<&EN92`X+C(N,"D@."XR+C```"YS:'-T<G1A8@`N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M``````(``````````@```````!X````````````````````!````````````
M````````$P```/;__V\"`````````"`"````````(`(```````"\````````
M``,`````````"````````````````````!T````+`````@````````#@`@``
M`````.`"````````2`D````````$`````P````@`````````&``````````E
M`````P````(`````````*`P````````H#````````%,$````````````````
M```!````````````````````+0````0````"`````````(`0````````@!``
M``````!``@````````,`````````"``````````8`````````#<````$````
M0@````````#`$@```````,`2````````N`4````````#````$`````@`````
M````&`````````!!`````0````8`````````>!@```````!X&````````#0`
M```````````````````$````````````````````1P````$````&````````
M`,`8````````P!@```````#<0@``````````````````(```````````````
M`````$T````!````!@````````"<6P```````)Q;````````+```````````
M``````````0```````````````````!3`````0````(`````````R%L`````
M``#(6P```````!L_```````````````````(````````````````````6P``
M``$````"`````````.2:````````Y)H```````#,````````````````````
M!````````````````````&D````!`````@````````"PFP```````+";````
M````4`0```````````````````0```````````````````!S`````0````,`
M````````*/L!```````H^P```````!`````````````````````(````````
M````````````>@````$````#`````````#C[`0``````./L````````0````
M````````````````"````````````````````($````&`````P````````!(
M^P$``````$C[````````P`$````````$``````````@`````````$```````
M```\````"`````,`````````"/T!```````(_0```````/@!````````````
M```````(``````````@`````````B@````$````#``````````#_`0``````
M`/\```````!P``````````````````````$````````(`````````(\````!
M`````P````````````(``````````0``````>`````````````````````@`
M``````````````````"5````"`````,`````````>``"``````!X``$`````
M`&@0```````````````````(````````````````````F@````$````P````
M````````````````>``!```````:`````````````````````0`````````!
M``````````$````#`````````````````````````)(``0``````HP``````
:``````````````$`````````````````````
